tests package
=============

.. automodule:: tests
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    tests.metadata

Submodules
----------

.. toctree::

   tests.conftest
   tests.test_disambigutors
   tests.test_function_dispatch
   tests.test_multistrategy_dispatch
   tests.test_structure
   tests.test_structure_attrs
   tests.test_unstructure

